==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Utilisateur"
 ,"Utilisateurs"

]
, "Groups"
: "Groupes"

, "Roles"
: "Rôles"

, "Applications"
: "Applications"

, "Containers"
: "Composants"

, "Shared Tags"
: "Marqueurs partagés"

, "Customfields"
: "Champs personnalisés"

, "Computers"
: "Ordinateurs"

, "Access Log, Access Logs"
: [
  "Journal d'accès"
 ,"Journaux d'accès"

]
, "Server Information"
: "Informations du serveur"

, "ActiveSync Devices"
: ""

, "Admin"
: "Administration"

, "Refresh"
: "Actualiser"

, "Name"
: "Nom"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Ordinateur"
 ,"Ordinateurs"

]
, "Default Addressbook for new contacts and groups"
: "Carnet d'adresse par défaut pour un nouveau contact ou groupe"

, "Group, Groups"
: [
  "Groupe"
 ,"Groupes"

]
, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Veuillez patienter"

, "Updating Memberships"
: "Mise à jour des appartenances"

, "Failed"
: "Échec"

, "Could not save group."
: "Échec de la sauvegarde du groupe."

, "Errors"
: "Erreurs"

, "Please fix the errors noted."
: "Veuillez corriger les erreurs indiquées."

, "Group Name"
: "Nom du groupe"

, "Description"
: "Description"

, "Visibility"
: "Visibilité"

, "Display in addressbook"
: "Afficher dans le carnet d'adresses"

, "Hide from addressbook"
: "Masquer dans le carnet d'adresses"

, "Saved in Addressbook"
: "Sauvegarder dans le carnet d'adresses"

, "Group Members"
: "Membres du groupe"

, "Transferring {0}..."
: "Transfert de {0} en cours..."

, "Add new group"
: "Ajouter un nouveau groupe"

, "Edit Group \"{0}\""
: "Éditer le groupe \"{0}\""

, "Enable Application"
: "Activer l'application"

, "Disable Application"
: "Désactiver l'application"

, "Settings"
: "Paramètres"

, "{0} Settings"
: "{0} paramètres"

, "enable application"
: "activer l'application"

, "disable application"
: "désactiver l'application"

, "settings"
: "paramètres"

, "Search:"
: "Chercher:"

, "disabled"
: "désactivé"

, "enabled"
: "activé"

, "unknown status ({0})"
: "statut inconnu ({0})"

, "Displaying application {0} - {1} of {2}"
: "Affichage des applications {0} - {1} de {2}"

, "No applications to display"
: "Pas d'application à afficher"

, "Order"
: "Ordre"

, "Status"
: "Statut"

, "Version"
: "Version"

, "Confirm"
: "Confirmer"

, "Do you really want to delete the selected groups?"
: "Confirmez-vous la suppression des groupes sélectionnés?"

, "Deleting group(s)..."
: "Suppression de(s) groupe(s)..."

, "Some error occurred while trying to delete the group."
: "Une erreur est survenue lors de la suppression du groupe."

, "Add Group"
: "Ajouter un groupe"

, "Edit Group"
: "Modifier un groupe"

, "Delete Group"
: "Supprimer un groupe"

, "Displaying groups {0} - {1} of {2}"
: "Affichage des groupes {0} - {1} de {2}"

, "No groups to display"
: "Pas de groupe à afficher"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Nom d'ordinateur"

, "IP Address"
: "Adresse IP"

, "Login Time"
: "Heure de connexion"

, "Logout Time"
: "Heure de déconnexion"

, "Client Type"
: "Type du client"

, "Session ID"
: "ID de session"

, "Login Name"
: "Identifiant"

, "Result"
: "Résultat"

, "user blocked"
: "utilisateur bloqué"

, "password expired"
: "Mot de passe obsolète"

, "user disabled"
: "utilisateur désactivé"

, "invalid password"
: "mot de passe invalide"

, "ambiguous username"
: "nom d'utilisateur ambigu"

, "user not found"
: "utilisateur inconnu"

, "failure"
: "échec"

, "success"
: "réussi"

, "Could not save role."
: "Le rôle n'a pas pu être sauvegardé."

, "Deleting role..."
: "Suppression du rôle..."

, "Some error occurred while trying to delete the role."
: "Une erreur est survenue lors de la suppression du rôle."

, "Rights"
: "Droits"

, "Members"
: "Membres"

, "Role Name"
: "Nom du rôle"

, "Role"
: "Rôle"

, "Add New Role"
: "Ajouter un nouveau rôle"

, "Edit Role \"{0}\""
: "Éditer le rôle \"{0}\""

, "Container Name"
: "Nom du composant"

, "Type"
: "Type"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Composant"
 ,"Composants"

]
, "Model"
: "Modèle"

, "personal"
: "Personnel"

, "shared"
: "Partagé"

, "Color"
: "Couleur"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Note au propriétaire"

, "Do you really want to delete the selected roles?"
: "Confirmez vous la suppression des rôles sélectionnés ?"

, "Deleting role(s)..."
: "Suppression de(s) rôle(s)..."

, "Add Role"
: "Ajouter un rôle"

, "Edit Role"
: "Modifier le rôle"

, "Delete Role"
: "Supprimer le rôle"

, "Displaying roles {0} - {1} of {2}"
: "Affichage des rôles {0} - {1} de {2}"

, "No roles to display"
: "Pas de rôle à afficher"

, "Do you really want to delete the selected tags?"
: "Confirmez la suppression des marqueurs sélectionnés ?"

, "Deleting tag(s)..."
: "Suppression des marqueurs..."

, "Add Tag"
: "Ajouter un tag"

, "Edit Tag"
: "Modifier un tag"

, "Delete Tag"
: "Supprimer un tag"

, "Displaying tags {0} - {1} of {2}"
: "Affichage des marqueurs {0} - {1} de {2}"

, "No tags to display"
: "Pas de marqueur à afficher"

, "Usage:&#160;"
: "Usage:&#160;"

, "Label"
: "Libellé"

, "Value"
: "Valeur"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  "Champ personnalisé"
 ,"Champs personnalisés"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: "Merci de configurer le stockage pour ce champ"

, "Record Class"
: "Type d'enregistrement"

, "Given record class not found"
: "Type d’enregistrement inconnu"

, "Cancel"
: "Annuler"

, "OK"
: "OK"

, "Configure store"
: "Configurer le stockage"

, "Custom field definition"
: "Définition du champ personnalisé"

, "Text"
: "Texte"

, "Textarea"
: ""

, "Number"
: "Nombre"

, "Date"
: "Date"

, "DateTime"
: "Date et Heure"

, "Time"
: "Heure"

, "Boolean"
: "Booléen"

, "Search Combo"
: "Liste de recherche"

, "Key Field"
: "Champ clé"

, "Record"
: "Enregistrement"

, "Record List"
: ""

, "Length"
: "Longueur"

, "Required"
: "Obligatoire"

, "Custom field additional properties"
: "Propriétés additionnelles du champ personnalisé"

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: "Ce champ personnalisé existe déjà. Choisissez un autre nom."

, "Enable Account"
: "Activer un compte"

, "Disable Account"
: "Désactiver un compte"

, "Reset Password"
: "Réinitialiser le mot de passe"

, "Reset Pin"
: ""

, "Display name"
: "Nom donné"

, "Login name"
: "Login"

, "Last name"
: "Nom"

, "First name"
: "Prénom"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Dernier login à"

, "Last login from"
: "Dernier login depuis"

, "Password changed"
: "Mot de passe mis à jour."

, "Expires"
: "Expiration"

, "Set new password"
: "Changer de mot de passe"

, "Please enter the new password:"
: "Veuillez saisir le nouveau mot de passe :"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Utilisateurs"

, "Samba User, Samba Users"
: [
  "Utilisateur Samba"
 ,"Utilisateurs Samba"

]
, "Email User, Email Users"
: [
  "Envoyer un courriel à l'utilisateur"
 ,"Envoyer un courriel aux utilisateurs"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: "Domaine non autorisé. Vérifierla configuration SMTP"

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Les mots de passes ne correspondent pas !"

, "Passwords match!"
: "Les mot s de passe correspondent"

, "Primary group"
: "Groupe principal"

, "Unix"
: "Unix"

, "Home Directory"
: "Répertoire personnel"

, "Login Shell"
: "Login Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Lecteur personnel"

, "Logon Time"
: "Heure de connexion"

, "never logged in"
: "jamais connecté"

, "Home Path"
: "Chemin du Home"

, "Logoff Time"
: "Heure de déconnexion"

, "never logged off"
: "jamais déconnecté"

, "Profile Path"
: "Chemin du profil"

, "Password Last Set"
: "Mot de passe défini le"

, "never"
: "jamais"

, "Logon Script"
: "Script d'ouverture de session"

, "Password Can Change"
: "le mot de passe peut être mis à jour"

, "not set"
: "non défini"

, "Password Must Change"
: "le mot de passe doit être mis à jour"

, "Kick Off Time"
: "Durée de bannissement"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "Pas de quota"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Taille actuelle de la boite mail"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Taille actuelle de Sieve"

, "Information"
: "Information"

, "Last Login"
: "Dernier login à"

, "Domain not allowed"
: "Domaine non autorisé"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "Alias email"

, "Add an alias address..."
: "Ajouter un alias..."

, "Forwarding to self"
: "Me transférer"

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: "Impossible de transférer vers une adresse qui est identique à une des votres"

, "Email Forward"
: "Transfert de courriels"

, "Add a forward address..."
: "Ajouter une adresse de transfert..."

, "Forward Only"
: "Transfert seulement"

, "Password confirmation"
: "Confirmation du mot de passe"

, "Repeat password"
: "Ressaisir le mot de passe"

, "Ok"
: "Ok"

, "Account"
: "Compte"

, "Password"
: "Mot de passe"

, "expired"
: "expiré"

, "blocked"
: "bloqué"

, "Invalid Status"
: "Statut invalide"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Le statut bloqué n'est possible que lorsqu'un utilisateur utilise un mauvais mot de passe. Il est impossible de l'utiliser ici."

, "don't know"
: "je ne sais pas"

, "Password set"
: "Mot de passe défini"

, "User groups"
: "Groupes d'utilisateurs"

, "User roles"
: "Rôles des utilisateurs"

, "Fileserver"
: "Serveur de fichier"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "Mise à jour du marqueur"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Contextes autorisés"

, "Context"
: "Contexte"

, "Account Rights"
: "Droits"

, "View"
: "Visualiser"

, "Use"
: "Utiliser"

, "Tag Name"
: "Nom"

, "Tag"
: "Marqueur"

, "Add New Tag"
: "Ajouter"

, "Edit Tag \"{0}\""
: "Éditer le marqueur \"{0}\""

, "Default IMAP user settings"
: "Configuration IMAP par défaut"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "gérer le journal d'accès"

, "delete access log entries"
: "effacer les entrées du journal d'accès"

, "manage accounts"
: "gérer les comptes"

, "add and edit users and groups, add group members, change user passwords"
: "ajouter et éditer les utilisateurs et les groupes, ajouter des membres de groupes, changer les mots de passe utilisateur"

, "manage applications"
: "gérer les applications"

, "enable and disable applications, edit application settings"
: "activer ou désactiver les applications, éditer les paramètres"

, "manage roles"
: "gérer les rôles"

, "add and edit roles, add new members to roles, add application rights to roles"
: "ajouter et éditer les rôles, ajouter des membres aux rôles, ajouter des droits pour les applications"

, "manage shared tags"
: "gérer les marqueurs partagés"

, "add, delete and edit shared tags"
: "ajouter, supprimer ou éditer un marqueur partagé"

, "manage computers"
: "gérer les ordinateurs"

, "add, delete and edit (samba) computers"
: "ajouter, supprimer ou éditer les ordinateurs (samba)"

, "manage containers"
: "Gérer les composants"

, "add, delete and edit containers and manage container grants"
: "Ajouter, modifier, supprimer des composants et gérer les droits"

, "manage customfields"
: "gérer les champs personnalisés"

, "add and edit customfields"
: "ajouter et modifier les champs personnalisés"

, "view access log"
: "afficher le journal d'accès"

, "view access log list"
: "afficher le journal des accès"

, "view accounts"
: "afficher les comptes"

, "view accounts list and details"
: "afficher la liste et le détail des utilisateurs"

, "view applications"
: "afficher les applications"

, "view applications list and details"
: "afficher la liste et le détail des applications"

, "view roles"
: "afficher les rôles"

, "view roles list and details"
: "afficher la liste et le détail des rôles"

, "view computers"
: "afficher les ordinateurs"

, "view computers list and details"
: "afficher la liste et le détail des ordinateurs"

, "view containers"
: "Voir les composants"

, "view personal and shared containers"
: "Voir les composants personnels et partagés"

, "view customfields"
: "voir les champs personnalisés"

, "view customfields list"
: "voir la liste des champs personnalisés"

, "view serverinfo"
: "voir les informations du serveur"

, "view serverinfo list"
: "voir la liste des informations du serveur"

, "view quota usage"
: ""

, "Your container has been changed"
: "Votre composant a été modifié"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Votre composant a été modifié par %1$s %2$s Note: %3$s"

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Utilisateur"

, "Access Log"
: "Journal d'accès"

, "Computer"
: "Ordinateur"

, "Group"
: "Groupe"

, "Application"
: "Application"

, "Config"
: ""

, "Container"
: "Composant"

, "Customfield"
: "Champ personnalisé"

, "Samba User"
: "Utilisateur Samba"

, "Email User"
: "Envoyer un courriel à l'utilisateur"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "Activer l'application"

, "Disable Application"
: "Désactiver l'application"

, "Settings"
: "Paramètres"

, "{0} Settings"
: "{0} paramètres"

, "Search:"
: "Chercher:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Affichage des applications {0} - {1} de {2}"

, "No applications to display"
: "Pas d'application à afficher"

, "Order"
: "Ordre"

, "Name"
: "Nom"

, "Status"
: "Statut"

, "Version"
: "Version"

, "Confirm"
: "Confirmer"

, "Do you really want to delete the selected groups?"
: "Confirmez-vous la suppression des groupes sélectionnés?"

, "Deleting group(s)..."
: "Suppression de(s) groupe(s)..."

, "Failed"
: "Échec"

, "Some error occurred while trying to delete the group."
: "Une erreur est survenue lors de la suppression du groupe."

, "Add Group"
: "Ajouter un groupe"

, "Edit Group"
: "Modifier un groupe"

, "Delete Group"
: "Supprimer un groupe"

, "Displaying groups {0} - {1} of {2}"
: "Affichage des groupes {0} - {1} de {2}"

, "No groups to display"
: "Pas de groupe à afficher"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Description"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Erreurs"

, "Please configure store for this field type"
: "Merci de configurer le stockage pour ce champ"

, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "Record Class"
: "Type d'enregistrement"

, "Given record class not found"
: "Type d’enregistrement inconnu"

, "Cancel"
: "Annuler"

, "OK"
: "OK"

, "Configure store"
: "Configurer le stockage"

, "Model"
: "Modèle"

, "Custom field definition"
: "Définition du champ personnalisé"

, "Text"
: "Texte"

, "Textarea"
: ""

, "Number"
: "Nombre"

, "Date"
: "Date"

, "DateTime"
: "Date et Heure"

, "Time"
: "Heure"

, "Boolean"
: "Booléen"

, "Search Combo"
: "Liste de recherche"

, "Key Field"
: "Champ clé"

, "Record"
: "Enregistrement"

, "Record List"
: ""

, "Type"
: "Type"

, "Label"
: "Libellé"

, "Length"
: "Longueur"

, "Required"
: "Obligatoire"

, "Custom field additional properties"
: "Propriétés additionnelles du champ personnalisé"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Groupe"
 ,"Groupes"

]
, "Customfield already exists. Please choose another name."
: "Ce champ personnalisé existe déjà. Choisissez un autre nom."

, "Customfield, Customfields"
: [
  "Champ personnalisé"
 ,"Champs personnalisés"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Valeur"

, "Default ({0})"
: ""

, "Computer Name"
: "Nom d'ordinateur"

, "Default Addressbook for new contacts and groups"
: "Carnet d'adresse par défaut pour un nouveau contact ou groupe"

, "Please wait"
: "Veuillez patienter"

, "Updating Tag"
: "Mise à jour du marqueur"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Veuillez corriger les erreurs indiquées."

, "Allowed Contexts"
: "Contextes autorisés"

, "Context"
: "Contexte"

, "Account Rights"
: "Droits"

, "View"
: "Visualiser"

, "Use"
: "Utiliser"

, "Tag Name"
: "Nom"

, "Color"
: "Couleur"

, "Transferring {0}..."
: "Transfert de {0} en cours..."

, "Tag"
: "Marqueur"

, "Add New Tag"
: "Ajouter"

, "Edit Tag \"{0}\""
: "Éditer le marqueur \"{0}\""

, "Do you really want to delete the selected tags?"
: "Confirmez la suppression des marqueurs sélectionnés ?"

, "Deleting tag(s)..."
: "Suppression des marqueurs..."

, "Add Tag"
: "Ajouter un tag"

, "Edit Tag"
: "Modifier un tag"

, "Delete Tag"
: "Supprimer un tag"

, "Displaying tags {0} - {1} of {2}"
: "Affichage des marqueurs {0} - {1} de {2}"

, "No tags to display"
: "Pas de marqueur à afficher"

, "Usage:&#160;"
: "Usage:&#160;"

, "Updating Memberships"
: "Mise à jour des appartenances"

, "Could not save role."
: "Le rôle n'a pas pu être sauvegardé."

, "Deleting role..."
: "Suppression du rôle..."

, "Some error occurred while trying to delete the role."
: "Une erreur est survenue lors de la suppression du rôle."

, "Rights"
: "Droits"

, "Members"
: "Membres"

, "Role Name"
: "Nom du rôle"

, "Role"
: "Rôle"

, "Add New Role"
: "Ajouter un nouveau rôle"

, "Edit Role \"{0}\""
: "Éditer le rôle \"{0}\""

, "Do you really want to delete the selected roles?"
: "Confirmez vous la suppression des rôles sélectionnés ?"

, "Deleting role(s)..."
: "Suppression de(s) rôle(s)..."

, "Add Role"
: "Ajouter un rôle"

, "Edit Role"
: "Modifier le rôle"

, "Delete Role"
: "Supprimer le rôle"

, "Displaying roles {0} - {1} of {2}"
: "Affichage des rôles {0} - {1} de {2}"

, "No roles to display"
: "Pas de rôle à afficher"

, "Access Log, Access Logs"
: [
  "Journal d'accès"
 ,"Journaux d'accès"

]
, "Groups"
: "Groupes"

, "Applications"
: "Applications"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domaine non autorisé. Vérifierla configuration SMTP"

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Les mots de passes ne correspondent pas !"

, "Passwords match!"
: "Les mot s de passe correspondent"

, "Primary group"
: "Groupe principal"

, "Unix"
: "Unix"

, "Home Directory"
: "Répertoire personnel"

, "Login Shell"
: "Login Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Lecteur personnel"

, "Login Time"
: "Heure de connexion"

, "never logged in"
: "jamais connecté"

, "Home Path"
: "Chemin du Home"

, "Logout Time"
: "Heure de déconnexion"

, "never logged off"
: "jamais déconnecté"

, "Profile Path"
: "Chemin du profil"

, "Password Last Set"
: "Mot de passe défini le"

, "never"
: "jamais"

, "Logon Script"
: "Script d'ouverture de session"

, "Password Can Change"
: "le mot de passe peut être mis à jour"

, "not set"
: "non défini"

, "Password Must Change"
: "le mot de passe doit être mis à jour"

, "Kick Off Time"
: "Durée de bannissement"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "Pas de quota"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Taille actuelle de la boite mail"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Taille actuelle de Sieve"

, "Information"
: "Information"

, "Last Login"
: "Dernier login à"

, "Domain not allowed"
: "Domaine non autorisé"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Ajouter un alias..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: "Me transférer"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Transfert seulement"

, "Password confirmation"
: "Confirmation du mot de passe"

, "Repeat password"
: "Ressaisir le mot de passe"

, "Ok"
: "Ok"

, "Account"
: "Compte"

, "First name"
: "Prénom"

, "Last name"
: "Nom"

, "Login name"
: "Login"

, "Password"
: "Mot de passe"

, "OpenID"
: "OpenID"

, "enabled"
: "activé"

, "disabled"
: "désactivé"

, "expired"
: "expiré"

, "blocked"
: "bloqué"

, "Invalid Status"
: "Statut invalide"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Le statut bloqué n'est possible que lorsqu'un utilisateur utilise un mauvais mot de passe. Il est impossible de l'utiliser ici."

, "Expires"
: "Expiration"

, "Visibility"
: "Visibilité"

, "Display in addressbook"
: "Afficher dans le carnet d'adresses"

, "Hide from addressbook"
: "Masquer dans le carnet d'adresses"

, "Saved in Addressbook"
: "Sauvegarder dans le carnet d'adresses"

, "Last login at"
: "Dernier login à"

, "don't know"
: "je ne sais pas"

, "Last login from"
: "Dernier login depuis"

, "Password set"
: "Mot de passe défini"

, "User groups"
: "Groupes d'utilisateurs"

, "User roles"
: "Rôles des utilisateurs"

, "Fileserver"
: "Serveur de fichier"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Utilisateur"
 ,"Utilisateurs"

]
, "Users"
: "Utilisateurs"

, "Samba User, Samba Users"
: [
  "Utilisateur Samba"
 ,"Utilisateurs Samba"

]
, "Email User, Email Users"
: [
  "Envoyer un courriel à l'utilisateur"
 ,"Envoyer un courriel aux utilisateurs"

]
, "Enable Account"
: "Activer un compte"

, "Disable Account"
: "Désactiver un compte"

, "Reset Password"
: "Réinitialiser le mot de passe"

, "Reset Pin"
: ""

, "Display name"
: "Nom donné"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Mot de passe mis à jour."

, "Set new password"
: "Changer de mot de passe"

, "Please enter the new password:"
: "Veuillez saisir le nouveau mot de passe :"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Nom du groupe"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Membres du groupe"

, "personal"
: "Personnel"

, "shared"
: "Partagé"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Note au propriétaire"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Composant"
 ,"Composants"

]
, "Container Name"
: "Nom du composant"

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Ordinateur"
 ,"Ordinateurs"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Rôles"

, "Containers"
: "Composants"

, "Shared Tags"
: "Marqueurs partagés"

, "Customfields"
: "Champs personnalisés"

, "Computers"
: "Ordinateurs"

, "Server Information"
: "Informations du serveur"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Administration"

, "Refresh"
: "Actualiser"

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "Adresse IP"

, "Client Type"
: "Type du client"

, "Session ID"
: "ID de session"

, "Login Name"
: "Identifiant"

, "Result"
: "Résultat"

, "user blocked"
: "utilisateur bloqué"

, "password expired"
: "Mot de passe obsolète"

, "user disabled"
: "utilisateur désactivé"

, "invalid password"
: "mot de passe invalide"

, "ambiguous username"
: "nom d'utilisateur ambigu"

, "user not found"
: "utilisateur inconnu"

, "failure"
: "échec"

, "success"
: "réussi"

, "Default IMAP user settings"
: "Configuration IMAP par défaut"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Votre composant a été modifié"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Votre composant a été modifié par %1$s %2$s Note: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""















































, "Application"
: "Application"

, "Group"
: "Groupe"

, "Customfield"
: "Champ personnalisé"

, "Config"
: ""

, "Access Log"
: "Journal d'accès"

, "User"
: "Utilisateur"

, "Samba User"
: "Utilisateur Samba"

, "Email User"
: "Envoyer un courriel à l'utilisateur"

, "Container"
: "Composant"

, "Computer"
: "Ordinateur"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
